@@ -1,19 +1,8 @@
 import click
-from lash.Exportables.config import config
-from lash.executor import abs_path_config
-from os import system, name
 from random import sample, randint
 from time import sleep
 import datetime
 
-config = config()
-
-
-@click.command(help='Get the config.py path')
-def getConfig():
-    print(f'\n[ {abs_path_config()} ]')
-
-
 @click.command(help='Generate random sequences')
 @click.option('-c', type=click.INT, default=5, show_default=True, help='Number of characters in random output')
 @click.option('-n', is_flag=True, help='Enable numbers', default=True, show_default=True)
@@ -44,36 +33,8 @@ def random(c, n, l, s, ul):
         print('Error: Please enable something to be randomized')
 
 
-@click.command()
-def taskkiller():
-    """\b
-        Kill multiple processes with single command
-
-        \b
-        This command is automation to close processes, to use it, you need
-        to put the process names in the configuration file so that they
-        can be processed one by one by the function.
-        \b
-        You can find the file in the package's installation folder, in the path
-        lash/Exportables/config.py, there you will have instructions on how to use it.
-    """
-    if len(config['black_list']) == 0:
-        print(f"""
-- None process name funded on <black_list> value
-To use this command correctly, you need add the processes names manually in\n[{abs_path_config()}]
-To more details use --help option
-    """)
-    if name == 'nt':
-        for p in config['black_list']:
-            system(f'taskkill /F /IM {p} /T') if name == 'nt' else system(f'pkill {p}')
-    else:
-        ...
-    print('\n<FUNCTION END>')
-
-
 import psutil
 
-
 def getListOfProcessSortedByMemory():
     listOfProcObjects = []
     for proc in psutil.process_iter():
