@@ -1,10 +1,11 @@
 import click
+from rich import print
 from lash.file_handler import *
 from lash.image_handler import *
 from lash.audio_handler import *
 from lash.video_handler import *
 from lash.app_math import *
-from lash.webTools import *
+from lash.web_scraping import *
 from lash.ExtraTools import *
 
 
@@ -12,17 +13,15 @@ from lash.ExtraTools import *
 @click.group('global')
 def Global():
     """\b
-        - Lash 1.2.4 by KevBoyz ~ https://github.com/KevBoyz/Lash
+        - Lash 1.2.5 by KevBoyz ~ https://github.com/KevBoyz/Lash
     """
 
 
 # Global Commands
-Global.add_command(getConfig)
 Global.add_command(random)
 Global.add_command(organize)
 Global.add_command(autoclick)
 Global.add_command(keyhold)
-Global.add_command(taskkiller)
 Global.add_command(monitor)
 
 # Groups declaration
@@ -32,7 +31,6 @@ Global.add_command(web)
 Global.add_command(Zip)
 Global.add_command(image)
 Global.add_command(calc)
-Global.add_command(yt)
 Global.add_command(video)
 Global.add_command(audio)
 
